# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Moo
Version:	2.005005
Release:	3.%{__distinit}%{__distvers}
Summary:	Minimalist Object Orientation (with Moose compatibility)
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Moo
Source0:	https://cpan.metacpan.org/authors/id/H/HA/HAARG/Moo-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Carp::Heavy)
BuildRequires:	perl(Class::Method::Modifiers) >= 1.10
BuildRequires:	perl(Config)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Filter::Util::Call)
BuildRequires:	perl(mro)
BuildRequires:	perl(Role::Tiny) >= 2.002003
BuildRequires:	perl(Scalar::Util) >= 1.00
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Defer) >= 2.006006
BuildRequires:	perl(Sub::Quote) >= 2.006006
BuildRequires:	perl(warnings)
# Optional Module Runtime
BuildRequires:	perl(Class::XSAccessor) >= 1.18
# Prefers Sub::Util, falls back to Sub::Name
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl(Sub::Util)
%else
BuildRequires:	perl(Sub::Name)
%endif
# Test Suite
BuildRequires:	perl(B::Deparse)
BuildRequires:	perl(base)
BuildRequires:	perl(Class::XSAccessor::Array)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(overload)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::More) >= 0.96
# Optional Tests
BuildRequires:	perl(CPAN::Meta::Requirements)
BuildRequires:	perl(Parse::CPAN::Meta) >= 1.4200
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Class::Method::Modifiers) >= 1.10
Requires:	perl(Class::XSAccessor) >= 1.18
Requires:	perl(Filter::Util::Call)
Requires:	perl(mro)
# Prefers Sub::Util, falls back to Sub::Name
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
Requires:	perl(Sub::Util)
%else
Requires:	perl(Sub::Name)
%endif

# Note: lib/Moo/HandleMoose.pm requires Moose modules.
# Moo::HandleMoose is used only if Moose has been loaded.
# So this is circular optional dependency definitely not suitable for Moo
# because Moo is re-implementation of Moose:
#   Class::MOP
#   Moose
#   Moose::Meta::Method::Constructor
#   Moose::Util::TypeConstraints
#
# MooX::ArrayRef is defined internally via %%INC

%description
This module is an extremely light-weight, high-performance Moose
replacement. It also avoids depending on any XS modules to allow simple
deployments. The name Moo is based on the idea that it provides almost -but
not quite- two thirds of Moose.

%prep
%setup -q -n Moo-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Moo.pm
%{perl_vendorlib}/oo.pm
%{perl_vendorlib}/Method/
%{perl_vendorlib}/Moo/
%{_mandir}/man3/Moo.3*
%{_mandir}/man3/Moo::Role.3*
%{_mandir}/man3/oo.3*

%changelog
* Sat Jul 15 2023 Paul Howarth <paul@city-fan.org> - 2.005005-3
- Drop support for Perl < 5.14, needing Devel::GlobalDestruction

* Fri Jan  6 2023 Paul Howarth <paul@city-fan.org> - 2.005005-1
- Update to 2.005005
  - Drop dependency on Test::Fatal
- Use SPDX-format license tag

* Mon Mar 29 2021 Paul Howarth <paul@city-fan.org> - 2.005004-1
- Update to 2.005004
  - Fix file set in %%INC in create_class_with_roles (CPAN RT#134845)

* Mon Mar 22 2021 Paul Howarth <paul@city-fan.org> - 2.005003-1
- Update to 2.005003
  - Remove MooseX::Types from developer prereqs
  - Recommend Sub::Util rather than Sub::Name, since Sub::Util is in core
  - Fix line numbers when using oo module (perl -Moo)
  - Adjust some author tests to rely less on external modules
  - Lower Exporter prereq to any version
  - Bump Role::Tiny prereq to 2.003004
  - Refactor and simplify role application code, as allowed by new Role::Tiny
    version
  - Switch to using normal strict+warnings rather than strictures for authors
  - Remove strictures from recommends, as Moo does not use it anywhere
  - Remove Task::Weaken prereq, as it served no purpose
  - Remove MRO::Compat prereq, using it only when user code does
  - Remove use of Devel::GlobalDestruction in code, only using
    Devel::GlobalDestruction::XS when it is available; Devel::GlobalDestruction
    is still a dependency on perl < 5.14 to facilitate the installation of the
    ::XS module
  - Moo now has no mandatory perl version specific dependencies; the version
    specific modules are now optional or not used, which means that code using
    Moo can be fatpacked on a new perl version without special cases, and it
    will work on older perl versions
  - Fix perl version check in global destruction code
  - Fix C3 test skipping properly when MRO::Compat not available on perl < 5.10
  - Silence 'once' warnings from Moo::_Utils
- Use %%license unconditionally

* Mon Dec  7 2020 Paul Howarth <paul@city-fan.org> - 2.004004-2
- Need runtime dependency on Devel::GlobalDestruction with Perl < 5.14

* Wed Nov 25 2020 Paul Howarth <paul@city-fan.org> - 2.004004-1
- Update to 2.004004
  - Fix error location test when using core Carp on perl 5.8.9-5.10.1

* Sun Nov 22 2020 Paul Howarth <paul@city-fan.org> - 2.004003-1
- Update to 2.004003
  - Remove Module::Runtime prerequisite
  - Internal code clean-ups
  - Added test for conflicts in extensions wrapping 'has' and similar subs

* Fri Apr 10 2020 Paul Howarth <paul@city-fan.org> - 2.004000-1
- Update to 2.004000
  - Minor documentation tweaks
  - Minor test tweaks
  - Refactor creation and installation of helper subs, allowing extensions to
    customize the behaviour more easily
  - Added is_class and make_class methods to Moo
  - Added make_role method to Moo::Role
  - Lower Scalar::Util dependency to 1.00
  - Fix unlikely failure to properly inflate Type::Tiny types to Moose under
    threads on perl 5.8

* Fri Oct 25 2019 Paul Howarth <paul@city-fan.org> - 2.003006-1
- Update to 2.003006
  - Always exclude helper subs (has, with, etc.) from the list of methods, even
    if they are installed later or wrapped with a modifier
  - Drop Devel::GlobalDestruction prerequisite unless using perl < 5.14
  - Fix preserving full accuracy of numbers in non-ref defaults
  - Fix tracking of stubs and constants as methods to be consistent and work
    properly with unusual ways of storing subs (CPAN RT#130050)
  - Fix test for modules broken by newer Moo versions when new enough
    CPAN::Meta version is not available
  - Fix undeferring subs before wrapping with a method modifier when subs to
    wrap are given as a list or array ref
  - Fix error reporting locations from Carp calls in DEMOLISH (CPAN RT#124845)
  - Fix extending attributes (has +) to allow overriding a default with a
    builder (CPAN RT#130361)
  - Fix re-throwing Moose inflation exceptions when examining exception objects
    on older Moose or Devel::StackTrace versions
  - Reorganized documentation related to Moose to improve clarity
  - Improved documentation of usage with namespace::clean
  - Various documentation tweaks
  - Update Role::Tiny prerequisite to 2.001004 to fix issues with re-importing
    Moo::Role
- Package LICENSE file

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 2.003004-6
- Perl 5.30 rebuild

* Fri Dec  1 2017 Paul Howarth <paul@city-fan.org> - 2.003004-1
- Update to 2.003004
  - Re-allow stubs for attribute parameters like isa or coerce (CPAN RT#123753)
  - Fix accidentally removed space in coderef error message (GH#33)
  - Fix test errors with old Carp versions

* Fri Nov 17 2017 Paul Howarth <paul@city-fan.org> - 2.003003-1
- Update to 2.003003
  - Test tweaks
  - Fix handling of code refs stored directly in the stash (for perl 5.28)
  - Consider inline packages with constants in them as being loaded
  - Stubs will be treated as methods that exist when inflating to Moose
  - Avoid loading overload.pm unless required
- Add patch to fix test failure in F-13/EL-6 where Carp can't find
  Carp/Heavy.pm with empty %%INC
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.96
  - perl(mro) always used in preference to perl(MRO::Compat)

* Wed Mar 29 2017 Paul Howarth <paul@city-fan.org> - 2.003002-1
- Update to 2.003002
  - Ensure tarball does not contain SCHILY headers

* Tue Mar  7 2017 Paul Howarth <paul@city-fan.org> - 2.003001-1
- Update to 2.003001
  - Fix +attributes replacing builder subs if parent attribute was defined with
    builder => $subref
  - Fix trigger with a default value and init_arg of undef
- Work around bug in GNU tar 1.15.1 that breaks extracting tarballs made with
  unknown extended attributes on old distributions
- BR: perl(Sub::Quote) ≥ 2.002001 for sanitize_identifier

* Mon Dec 12 2016 Paul Howarth <paul@city-fan.org> - 2.003000-1
- Update to 2.003000
  - Fix create_class_with_roles being used multiple times with the same
    packages
  - Fix edge case with @ISA assignment on perl 5.10.0
  - Minor test adjustments
  - Fix handles on oddly named attributes
  - Make has options linkable in documentation
  - Sub::Quote and Sub::Defer have been split into a separate dist

* Tue Nov  1 2016 Paul Howarth <paul@city-fan.org> - 2.002005-1
- Update to 2.002005
  - Fix accessor extensions that need captured variables for clearers and
    predicates (CPAN RT#118453)
  - Avoid relying on '.' being in @INC in tests
  - Fix Sub::Quote test when run with perl -C or PERL_UNICODE on perl 5.10
    (CPAN RT#117844)
  - Improved error messages for invalid sub names in Sub::Quote
    (CPAN RT#116416, CPAN RT#117711)
  - Clarify meta method documentation
  - Bump Role::Tiny prereq version to get stub in role fix (CPAN RT#116674)
- Fix FTBFS when perl is not in the minimal buildroot

* Tue Jun 28 2016 Paul Howarth <paul@city-fan.org> - 2.002004-1
- Update to 2.002004
  - Fixed another case of local functions interfering with generated code
    (CPAN RT#115655)
  - Prevent infinite recursion on some Moose metaclass inflation errors

* Thu Jun 23 2016 Paul Howarth <paul@city-fan.org> - 2.002003-1
- Update to 2.002003
  - Prevent local functions with same names as core functions from interfering
    with generated code (CPAN RT#115529)
  - Work around nmake bug that corrupts commands that include slashes
    (CPAN RT#115518)
  - Fix tests to work when lexical features are enabled outside of our control
    (such as with cperl)
  - Fix tests on perl 5.6

* Tue Jun 21 2016 Paul Howarth <paul@city-fan.org> - 2.002002-1
- Update to 2.002002
  - Use Carp::croak rather than die to improve reported error locations
    (CPAN RT#109844, CPAN RT#109632, CPAN RT#102622)
  - Removed Method::Inliner module, which was never intended to ship with Moo
    and was undocumented, untested, and unused on CPAN
  - Require Role::Tiny 2.000002 for fixes to method modifiers being applied via
    multiple role composition paths (CPAN RT#106668)
  - Delay loading Class::Method::Modifiers until we actually need it
  - Fix an explosion that could happen if meta inflation was attempted part way
    through Moo's bootstrapping process, which was possible via a
    CORE::GLOBAL::bless override (CPAN RT#113743)
  - Accessor subs will be generated immediately, rather than being partially
    deferred; the deferral added extra sub layers and the delayed compilation
    didn't provide any real benefit for them
  - Numeric values used as defaults will be inlined as numbers rather than
    strings
  - Numerous test cleanups and additional test coverage
  - Fixed a typo in Sub::Defer docs (CPAN RT#113416)
  - Deferred subs (including constructors) will always be named properly, even
    if neither Sub::Name nor Sub::Util are available; this improves
    compatibility with namespace::autoclean, among other things (once the sub
    is undeferred, it may not be given a correct name if Sub::Name or Sub::Util
    aren't available)
  - Added Sub::Quote::sanitize_identifier to generate an identifier from an
    arbitrary string
  - Sub::Defer::defer_info is now exportable
  - Improved documentation for Sub::Quote
  - Fix quoted subs with no_defer ignoring no_install option (CPAN RT#114605)
  - Internals of Sub::Quote were refactored
  - Error message when @ISA changes now includes the location that the
    constructor was generated
  - Original invoker will be used when calling a non-Moo parent constructor
    (CPAN RT#115189)
  - Added testing for preserving context into quote_sub subs (CPAN RT#114511)
  - quote_sub context options will be used even when zero (CPAN RT#114512)
  - Sub::Defer::defer_sub gained attributes option to specify sub attributes
  - Sub::Quote::quote_sub gained attributes option to specify sub attributes
  - Fix handling of Carp < 1.12
- BR: perl-generators where available
- Simplify find command using -delete

* Fri Mar  4 2016 Paul Howarth <paul@city-fan.org> - 2.001001-1
- Update to 2.001001
  - Fixed order of attribute value being set and trigger running when there is
    an isa check present (CPAN RT#112677)
  - Corrected LIFECYCLE METHODS to be a head1 section rather than head2

* Tue Mar  1 2016 Paul Howarth <paul@city-fan.org> - 2.001000-1
- Update to 2.001000
  Documentation:
  - Added documentation for has's ability to accept an arrayref of attribute
    names to create with the same options
  - Removed mention that we may not call BUILDARGS, since that behavior was
    removed in 2.000002
  - Reorganized documentation of class methods to separate those provided as a
    public API (new/does/meta) from those used by Moo in the object lifecycle
    (BUILDARGS/FOREIGNBUILDARGS/BUILD/DEMOLISH)
  - Updated documentation of most class methods for clarity
  - Updated BUILDARGS documentation to show an around rather than just
    overriding
  - Added examples to FOREIGNBUILDARGS and BUILD
  - Added explicit documentation for DOES and meta methods
  Fixes:
  - Fixed grammar in error message when @ISA is changed unexpectedly before a
    constructor is fully generated
  - Fixed Moo classes and Sub::Quote subs in packages that are nearly 252
    characters long
  - Fixed Sub::Defer::undefer_package emitting warnings
  - Fixed detection of constructors that have already been inlined
  Performance:
  - The generated code in constructors and setters has had a number of
    microoptimizations applied
  - Deferred subs (and quoted subs like some accessors) in roles will be
    undefered before copying them to classes; this prevents the need for a goto
    on every call, which would slow down the subs
  - Fixed Moose inflation code resulting in constructors with deferred wrappers
  Other:
  - Recommend Sub::Name 0.08, which fixes a memory leak
  - The values given to BUILD subs will be the original values passed to new,
    rather than after coercions have been applied; this brings the behavior in
    line with Moose

* Fri Jul 24 2015 Paul Howarth <paul@city-fan.org> - 2.000002-1
- Update to 2.000002
  - BUILDARGS will now always be called on object creation, even if no
    attributes exist
  - Fix required attributes with spaces or other odd characters in init_arg
  - Fix (is => 'lazy', required => 1, init_arg => undef), which previously
    didn't think it provided a builder
  - Under 'no Moo::sification', prevent automatic Moose metaclass inflation
    from ->meta calls
  - Don't load Moo::Role for a ->does check if no roles could exist
  - Make global destruction test more robust from outside interference
  - Fix false default values satisfying required attributes
  - Fix Moose attribute delegation to a Moo class via a wildcard
  - Work around case where Sub::Util is loadable but doesn't provide
    Sub::Util::set_subname
  - Skip thread tests on perl 5.8.4 and below where threads are extremely
    unreliable
  - Allow stub methods (e.g. sub foo;) to be overwritten by accessors or other
    generated methods (CPAN RT#103804)

* Fri Jun 26 2015 Paul Howarth <paul@city-fan.org> - 2.000001-3
- Perl 5.22 rebuild

* Tue Mar 17 2015 Paul Howarth <paul@city-fan.org> - 2.000001-1
- Update to 2.000001
  - Fix how we pick between Sub::Name and Sub::Util if they are both loaded;
    this fixes how we interact with Moose in some cases (CPAN RT#102729, GH#15)

* Tue Mar  3 2015 Paul Howarth <paul@city-fan.org> - 2.000000-1
- Update to 2.000000
  Incompatible Changes
  - Fatal warnings and the other additional checks from the strictures module
    will no longer be applied to modules using Moo or Moo::Role; we now only
    apply strict and (non-fatal) warnings, matching the behavior of Moose
  - Classes without attributes used to store everything passed to ->new in the
    object; this has been fixed to not store anything in the object, making it
    consistent with classes that had attributes
  - Moo will now pass __no_BUILD__ to parent constructors when inheriting from
    a Moose or Class::Tiny class, to prevent them from calling BUILD functions;
    Moo calls the BUILD functions itself, which previously led to them being
    called multiple times
  - Attempting to replace an existing constructor, or modify one that has been
    used, will throw an error (this includes adding attributes); previously,
    this would result in some attributes being silently ignored by the
    constructor
  - If a class's @ISA is modified without using 'extends' in a way that affects
    object construction, Moo will detect this and throw an error; this can
    happen in code that uses ->load_components from Class::C3::Componentised,
    which is common in DBIx::Class modules
  Bug Fixes
  - Fix calling class methods on Moo::HandleMoose::FakeMetaClass, such as
    modules scanning all classes
  Miscellaneous
  - use Sub::Util instead of Sub::Name if available

* Wed Jan 21 2015 Paul Howarth <paul@city-fan.org> - 1.007000-1
- Update to 1.007000
  - Fix Moose metaclass inflation of Method::Generate::Constructor
    (CPAN RT#101111)
  - Clarify behaviour of clearers for non-lazy attribute defaults
  - Add Sub::Defer::undefer_package to undefer all subs from a given package
  - Existing attributes will no longer be overwritten when composing roles;
    previously, the attribute configuration used by the constructor would be
    overridden but the attribute methods would not be, which caused a mismatch
    in attribute behaviour
  - Link to Type::Tiny in docs rather than MooX::Types::MooseLike
  - Document exports of Sub::Defer
  - Fix capture_unroll usage in inlinify example
  - Fix needless re-assigning of variables in generated Sub::Quote subs
  - Fix global destruction test to work when perl path has spaces

* Thu Oct 23 2014 Paul Howarth <paul@city-fan.org> - 1.006001-1
- Update to 1.006001
  - Name the ->DOES method installed by Role::Tiny
  - Don't apply threading workarounds on non-threaded perls, even if module for
    it is loaded by something
  - Avoid loading base.pm and just set @ISA manually
  - Fix some Pod links to Class::Method::Modifiers
  - Fix applying roles with multiple attributes with defaults to objects
    (CPAN RT#99217)
  - Fix Moose inheriting from a Moo class that inherits from a non-M* class
    when the Moose class is not made immutable
  - Fix ->does method on Moose child classes of Moo classes

* Thu Oct  2 2014 Paul Howarth <paul@city-fan.org> - 1.006000-3
- Import from Fedora

* Fri Aug 29 2014 Jitka Plesnikova <jplesnik@redhat.com> - 1.006000-2
- Perl 5.20 rebuild

* Fri Aug 22 2014 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.006000-1
- Upstream update
- Reflect deps having changed

* Tue Jul 22 2014 Petr Pisar <ppisar@redhat.com> - 1.005000-1
- 1.005000 bump

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.003001-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Oct 18 2013 Miro Hrončok <mhroncok@redhat.com> - 1.003001-2
- Role::Tiny is now ≳ 1.003002

* Fri Oct 18 2013 Miro Hrončok <mhroncok@redhat.com> - 1.003001-1
- 1.003001 bump
- Source URL was changed in this release

* Fri Aug 16 2013 Jitka Plesnikova <jplesnik@redhat.com> - 1.003000-2
- Added perl(Moo::Conflicts) to provides

* Fri Aug 09 2013 Jitka Plesnikova <jplesnik@redhat.com> - 1.003000-1
- 1.003000 bump
- Update source link
- Specify all dependencies

* Thu Aug 08 2013 Petr Pisar <ppisar@redhat.com> - 1.002000-3
- Perl 5.18 rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.002000-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 07 2013 Iain Arnell <iarnell@gmail.com> - 1.002000-1
- Update to latest upstream version

* Fri Apr 19 2013 Iain Arnell <iarnell@gmail.com> - 1.001000-1
- Update to latest upstream version

* Fri Feb 15 2013 Iain Arnell <iarnell@gmail.com> - 1.000008-1
- Update to latest upstream version

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.000007-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jan 05 2013 Iain Arnell <iarnell@gmail.com> - 1.000007-1
- Update to latest upstream version

* Sat Oct 27 2012 Iain Arnell <iarnell@gmail.com> - 1.000005-1
- Update to latest upstream version

* Fri Oct 19 2012 Iain Arnell <iarnell@gmail.com> - 1.000004-1
- Update to latest upstream version

* Sun Sep 09 2012 Iain Arnell <iarnell@gmail.com> - 1.000003-1
- Update to latest upstream version

* Sun Jul 29 2012 Iain Arnell <iarnell@gmail.com> - 1.000001-1
- Update to latest upstream version

* Thu Jul 26 2012 Iain Arnell <iarnell@gmail.com> - 1.000000-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jul 20 2012 Iain Arnell <iarnell@gmail.com> - 1.000000-1
- Update to latest upstream version
- Explicity require Role::Tiny ≳ 1.001003

* Tue Jul 17 2012 Iain Arnell <iarnell@gmail.com> - 0.091014-1
- Update to latest upstream version

* Sat Jun 23 2012 Petr Pisar <ppisar@redhat.com> - 0.091007-2
- Perl 5.16 rebuild

* Sat May 19 2012 Iain Arnell <iarnell@gmail.com> - 0.091007-1
- Update to latest upstream version

* Mon Apr 02 2012 Iain Arnell <iarnell@gmail.com> - 0.009014-1
- Update to latest upstream version

* Fri Jan 06 2012 Iain Arnell <iarnell@gmail.com> - 0.009013-1
- Update to latest upstream version

* Sun Nov 20 2011 Iain Arnell <iarnell@gmail.com> - 0.009012-1
- Update to latest upstream version
- Filter private requires/provides

* Mon Oct 10 2011 Iain Arnell <iarnell@gmail.com> - 0.009011-1
- Update to latest upstream version

* Sun Oct 02 2011 Iain Arnell <iarnell@gmail.com> - 0.009010-1
- Specfile autogenerated by cpanspec 1.79
